Module blaxel.livekit.tools
===========================

Functions
---------

`bl_tools(tools_names: list[str], **kwargs) ‑> list[livekit.agents.llm.tool_context.FunctionTool]`
:   

`get_livekit_tools(tools: list[blaxel.core.tools.types.Tool]) ‑> list[livekit.agents.llm.tool_context.FunctionTool]`
:   

`livekit_coroutine(tool: blaxel.core.tools.types.Tool)`
: